crnt4sbml.Cgraph
======================

.. currentmodule:: crnt4sbml

.. autoclass:: Cgraph

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Cgraph.__init__
      ~Cgraph.get_species
      ~Cgraph.get_complexes
      ~Cgraph.get_reactions
      ~Cgraph.get_deficiency
      ~Cgraph.get_dim_equilibrium_manifold
      ~Cgraph.get_ode_system
      ~Cgraph.get_a
      ~Cgraph.get_b
      ~Cgraph.get_s
      ~Cgraph.get_y
      ~Cgraph.get_lambda
      ~Cgraph.get_psi
      ~Cgraph.get_graph
      ~Cgraph.get_g_nodes
      ~Cgraph.get_g_edges
      ~Cgraph.get_network_dimensionality_classification
      ~Cgraph.get_linkage_classes
      ~Cgraph.get_linkage_classes_deficiencies
      ~Cgraph.get_if_cgraph_weakly_reversible
      ~Cgraph.get_weak_reversibility_of_linkage_classes
      ~Cgraph.get_number_of_terminal_strong_lc_per_lc
      ~Cgraph.print
      ~Cgraph.plot
      ~Cgraph.plot_save
